Uses of Class org.openqa.selenium.server.FrameAddress (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.FrameAddress

Packages that use FrameAddress
org.openqa.selenium.server | Provides the core Selenium Server classes.

Uses of FrameAddress in org.openqa.selenium.server

Methods in org.openqa.selenium.server that return FrameAddress
`FrameAddress` | `CommandQueue.getFrameAddress()`
`static FrameAddress` | `FrameAddress.make(java.lang.String windowName, java.lang.String localFrameAddress)`
`static FrameAddress` | `FrameGroupCommandQueueSet.makeFrameAddress(java.lang.String seleniumWindowName, java.lang.String localFrameAddress)`

Methods in org.openqa.selenium.server with parameters of type FrameAddress
`RemoteCommand` | `FrameGroupCommandQueueSet.handleCommandResult(java.lang.String commandResult, FrameAddress incomingFrameAddress, java.lang.String uniqueId, boolean justLoaded, java.util.List<?> jsWindowNameVars)` Accepts a command reply, and retrieves the next command to run.
`void` | `CommandQueue.setFrameAddress(FrameAddress frameAddress)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.